============
Pseudopeople
============

Pseudopeople is a package intended to add configurable noise to a simulated
census-scale data-set written using standard scientific Python tools.

**Pseudopeople requires Python 3.7-3.10 to run**

You can install ``pseudopeople`` from PyPI with pip:

  ``> pip install pseudopeople``

or build it from source with

  ``> git clone https://github.com/ihmeuw/pseudopeople.git``

  ``> cd pseudopeople``

  ``> python setup.py install``

This will make the ``pseudopeople`` library available to python and install a
command-line executable called ``...`` that you can use to verify your
installation with

  ``> ... test``
